@@ -60,8 +60,13 @@
 #' call to a position adjustment function.
 #'
 #' @param arrow specification for arrow heads, as created by arrow()
+#' 
+#' @param arrow.fill fill color to use for the arrow head (if closed). `NULL` 
+#' means use colour aesthetic.
 #'
 #' @param lineend Line end style (round, butt, square)
+#' 
+#' @param linejoin Line join style (round, mitre, bevel).
 #'
 #' @param n The number of points to create for each segment
 #'
@@ -132,7 +137,7 @@ StatLink <- ggproto('StatLink', Stat,
                 index = seq(0, 1, length.out = n),
                 group = i
             )
-            cbind(path, data[rep(i, n), extraCols])
+            cbind(path, data[rep(i, n), extraCols, drop = FALSE])
         })
         do.call(rbind, data)
     },
